@@ -2,14 +2,14 @@
 
 #This script has been taken from a forum somewhere in the vast Internet space :)
 #Its purpose is to generate the HTML from POD and apply some CSS as it will look like on CPAN
-#Typical use: perl pod2cpanhtml.pl lib/PDF/Table.pm pdftable.html
+#Typical use: perl pod2cpanhtml.pl lib/PDF/Table.pod pdftable.html
 
 use strict;
 use warnings;
 use Pod::Simple::HTML;
 
-our $VERSION = '1.001'; # VERSION
-my $LAST_UPDATE = '1.000'; # manually update whenever code is changed
+our $VERSION = '1.004'; # VERSION
+our $LAST_UPDATE = '1.000'; # manually update whenever code is changed
 
 my $parser = Pod::Simple::HTML->new();
 
@@ -28,7 +28,10 @@ if (defined $ARGV[1]) {
 }
 
 $parser->index(1);
-$parser->html_css('http://search.cpan.org/s/style.css');
+# site no longer exists. TBD see if there is some good replacement out there,
+# preferably one that doesn't require turning a phone to landscape mode in
+# order to see text at a decent size.
+#$parser->html_css('http://search.cpan.org/s/style.css');
 
 $parser->output_fh(*$OUT);
 $parser->parse_file(*$IN);
